/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Profile Manager.
 *
 * The Initial Developer of the Original Code is
 * the Mozilla Foundation.
 * Portions created by the Initial Developer are Copyright (C) 2010
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *    Jonathan Griffin <jgriffin@mozilla.com>
 *    Mark Cote <mcote@mozilla.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var gApps;
var gAppName;
var gDefaultIndex;
var gDefaultApp;
var gApp;
var gBundle;

/**
 * Add a row to the main tree control representing an application version.
 * @param path - the full path of the application
 * @param version - the app's version
 * @param isDefault - true if the app is the default app
 */
function addtreechild(path, version, isdefault) {
  var treechildren = document.getElementsByTagName('treechildren')[0];
  var treeitem = document.createElement('treeitem');
  var treerow = document.createElement('treerow');
  var cell = document.createElement('treecell');
  cell.setAttribute('label', path);
  treerow.appendChild(cell);
  cell = document.createElement('treecell');
  cell.setAttribute('label', version);
  treerow.appendChild(cell);
  cell = document.createElement('treecell');
  if (isdefault == 'true')
    cell.setAttribute('properties', 'isdefault');
  else
    cell.setAttribute('properties', 'isnotdefault');
  cell.setAttribute('value', isdefault);
  treerow.appendChild(cell);
  treeitem.appendChild(treerow);
  treechildren.appendChild(treeitem);
}

/**
 * Handle the mousedown event on the tree element; if the event was
 * triggered over the 'default' column, mark the appropriate profile
 * as default
 */
function onTreeMouseDown(event) {
  var tree = document.getElementById("app-tree");
  var tbo = tree.treeBoxObject;

  // get the row, col and child element at the point
  var row = { }, col = { }, child = { };
  var selectedRow = -1;
  tbo.getCellAt(event.clientX, event.clientY, row, col, child);
  if (col.value && typeof(col.value) == "object" && 
      col.value.id == "default" && row.value > -1) {
    selectedRow = row.value;
  }

  if (selectedRow == -1)
    return;

  gDefaultIndex = selectedRow;
  for (var i = 0; i < tree.view.rowCount; i++) {
    var item = tree.view.getItemAtIndex(i);
    var cells = item.getElementsByTagName("treecell");
    for (var j = 0; j < cells.length; j++) {
      if (cells[j].getAttribute('value') == 'true' ||
          cells[j].getAttribute('value') == 'false') {
        if (i == gDefaultIndex) {
          cells[j].setAttribute('properties', 'isdefault');
          cells[j].setAttribute('value', 'true');
        }
        else {
          cells[j].setAttribute('properties', 'isnotdefault');
          cells[j].setAttribute('value', 'false');
        }
      }
    }
  }
}

/**
 * Handle the load event
 */
function onload() {
  // set some globals to values passed into the window
  gApps = window.arguments[0].in.apps;
  gAppName = window.arguments[0].in.appname;
  gDefaultIndex = window.arguments[0].in.defaultIndex;
  gDefaultApp = window.arguments[0].in.defaultApp;
  if (gDefaultIndex == undefined)
    gDefaultIndex = -1;
  gApp = window.arguments[0].in.app;
  gBundle = document.getElementById("bundle_profileManager");

  // populate the tree control
  document.getElementsByTagName("dialogheader")[0].
           setAttribute("description", gAppName);
  if (gDefaultIndex == -1 && gDefaultApp)
    addtreechild(gDefaultApp, getAppVersion(gDefaultApp), 'true');
  for (var i = 0; gApps && i < gApps.length; i++) {
    addtreechild(gApps[i].path, 
                 gApps[i].version, i == gDefaultIndex ? 'true' : 'false');
  }

  centerDialogToParent();
}

/**
 * Handle a click of the 'close button', by setting the window's 'out'
 * parameters according to the current contents of the tree control.
 */
function doClose() {
  var tree = document.getElementsByTagName('tree')[0];
  var apps = [];
  for (var i = 0; i < tree.view.rowCount; i++) {
    // omit the default row if wasn't user set
    if (!(tree.view.getCellValue(i, tree.columns.getColumnAt(2)) == 'true' &&
        gDefaultIndex == -1))
      apps.push(tree.view.getCellText(i, tree.columns.getColumnAt(0)));
  }
  window.arguments[0].out = {apps: apps, defaultIndex: gDefaultIndex};
  window.close();
  return true;
}

/**
 * Use the file picker dialog to add another item to the list.
 */
function doAdd() {
  var thefile = chooseBinaryWithFilePicker(gApp);
  if (thefile) {
    let appPresent = false;
    let tree = document.getElementsByTagName('tree')[0];
    for (let i = 0; i < tree.view.rowCount; i++) {
      if (tree.view.getCellText(i, tree.columns.getColumnAt(0)).toLowerCase() ==
          thefile.path.toLowerCase()) {
        appPresent = true;
      }
    }

    // don't add duplicate values
    if (!appPresent) {
      addtreechild(thefile.path, getAppVersion(thefile.path), 'false');
    }
  }
}

/**
 * Delete the selected item from the tree control.
 */
function doDelete() {
  var tree = document.getElementsByTagName('tree')[0];
  if (!tree.view.selection.count) {
    alert(gBundle.getString("deleteNoItemSelectedAlert"));
    return;
  }

  var treeitem = tree.view.getItemAtIndex(tree.view.selection.currentIndex);
  treeitem.parentNode.removeChild(treeitem);

  // recalculate gDefaultIndex if necessary
  if (gDefaultIndex > -1) {
    gDefaultIndex = -1;
    for (var i = 0; i < tree.view.rowCount; i++) {
      if (tree.view.getCellValue(i, tree.columns.getColumnAt(2)) == 'true')
        gDefaultIndex = i;
    }
  }
}
