/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998-1999
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Jeffrey Hammel <jhammel@mozilla.com>
 *   Jonathan Griffin <jgriffin@mozilla.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

// common routines used by dialogs

var profile;
var profileService;
var appName;
var ProfileManager;

/**
 * Center the dialog to the parent window.
 */
function centerDialogToParent() {
  // size to content, so that outerWidth/outerHeight are accurate
  window.sizeToContent();

  // calculate new offsets based on parent's current position and size
  var xOffset = window.opener.screenX + window.opener.outerWidth/2 - 
                window.outerWidth/2;
  var yOffset = window.opener.screenY + window.opener.outerHeight/2 - 
                window.outerHeight/2;

  xOffset = ( xOffset > 0 ) ? xOffset : 0;
  yOffset = ( yOffset > 0 ) ? yOffset : 0;
  window.moveTo( xOffset, yOffset);
}

/**
 * Handle dialog startup, by saving the parameters passed to the window,
 * and updating the dialogheader with the profile name, if appropriate.
 */
function dialogStartup() {
  // set window arguments to globals
  profile = window.arguments[0].in.profile;
  profileService = window.arguments[0].in.gProfileService;
  appName = window.arguments[0].in.appName;
  ProfileManager = window.arguments[0].in.ProfileManager;

  // fix the markup if the profile is passed in
  if (profile) {
    var dialogHeader = document.getElementsByTagName('dialogheader')[0];
    dialogHeader.setAttribute('description', profile.name);
  }

  centerDialogToParent();
}

/**
 * Handle the the onclick event for a 'Change location' button by displaying
 * an nsIFilePicker that allows the user to select a directory.
 * @param id - the id of the text element to fill with the directory's
 *             name, if the user presses OK in the file picker dialog
 * @param title - the text to use as the file picker's title
 */
function onClick_ChangeLocation(id, title) {
  var picker = getFilePicker();
  picker.init(window,
              title,
              Ci.nsIFilePicker.modeGetFolder);
  var result = picker.show();
  if (result == Ci.nsIFilePicker.returnCancel)
    return;

  document.getElementById(id).value = picker.file.path;
}

